@@ -4,7 +4,7 @@
 .. versionadded:: 0.5.0
 """
 from ctypes import (CFUNCTYPE, POINTER, c_void_p, c_int, c_size_t, c_double,
-                    c_char_p, c_uint, c_ubyte, c_bool)
+                    c_char_p, c_ubyte, c_bool)
 from wand.cdefs.wandtypes import c_ssize_t, c_magick_char_p
 
 __all__ = ('MagickProgressMonitor', 'load')
@@ -23,7 +23,7 @@ __all__ = ('MagickProgressMonitor', 'load')
 #:
 #: .. note::
 #:
-#:     TODO - Move to isoalted module. This shouldn't be defined at time of
+#:     TODO - Move to isolated module. This shouldn't be defined at time of
 #:     mload. It might be wiser to create a method to allow the user to ask for
 #:     C-function-type.
 MagickProgressMonitor = CFUNCTYPE(c_bool,
@@ -225,8 +225,11 @@ def load(lib, IM_VERSION):
         except AttributeError:
             lib.MagickCompareImageLayers = None
     else:
-        lib.MagickCompareImagesLayers.argtypes = [c_void_p, c_int]
-        lib.MagickCompareImagesLayers.restype = c_void_p
+        try:
+            lib.MagickCompareImagesLayers.argtypes = [c_void_p, c_int]
+            lib.MagickCompareImagesLayers.restype = c_void_p
+        except AttributeError:
+            lib.MagickCompareImagesLayers = None
     if IM_VERSION >= 0x708:
         try:
             lib.MagickComplexImages.argtypes = [c_void_p, c_int]
@@ -500,7 +503,7 @@ def load(lib, IM_VERSION):
     lib.MagickGetImageHistogram.argtypes = [c_void_p, POINTER(c_size_t)]
     lib.MagickGetImageHistogram.restype = POINTER(c_void_p)
     lib.MagickGetImageInterlaceScheme.argtypes = [c_void_p]
-    lib.MagickGetImageInterlaceScheme.restype = c_bool
+    lib.MagickGetImageInterlaceScheme.restype = c_int
     lib.MagickGetImageIterations.argtypes = [c_void_p]
     lib.MagickGetImageIterations.restype = c_size_t
     lib.MagickGetImageInterpolateMethod.argtypes = [c_void_p]
@@ -527,8 +530,8 @@ def load(lib, IM_VERSION):
     lib.MagickGetImageOrientation.argtypes = [c_void_p]
     lib.MagickGetImageOrientation.restype = c_int
     lib.MagickGetImagePage.argtypes = [
-        c_void_p, POINTER(c_uint), POINTER(c_uint), POINTER(c_int),
-        POINTER(c_int)
+        c_void_p, POINTER(c_size_t), POINTER(c_size_t), POINTER(c_ssize_t),
+        POINTER(c_ssize_t)
     ]
     lib.MagickGetImagePage.restype = c_bool
     lib.MagickGetImagePixelColor.argtypes = [
@@ -801,14 +804,24 @@ def load(lib, IM_VERSION):
     lib.MagickPreviewImages.restype = c_void_p
     lib.MagickPreviousImage.argtypes = [c_void_p]
     lib.MagickPreviousImage.restype = c_bool
-    lib.MagickQuantizeImage.argtypes = [
-        c_void_p, c_size_t, c_int, c_size_t, c_bool, c_bool
-    ]
-    lib.MagickQuantizeImage.restypes = c_bool
-    lib.MagickQuantizeImages.argtypes = [
-        c_void_p, c_size_t, c_int, c_size_t, c_bool, c_bool
-    ]
-    lib.MagickQuantizeImages.restype = c_bool
+    if IM_VERSION < 0x700:
+        lib.MagickQuantizeImage.argtypes = [
+            c_void_p, c_size_t, c_int, c_size_t, c_bool, c_bool
+        ]
+        lib.MagickQuantizeImage.restypes = c_bool
+        lib.MagickQuantizeImages.argtypes = [
+            c_void_p, c_size_t, c_int, c_size_t, c_bool, c_bool
+        ]
+        lib.MagickQuantizeImages.restype = c_bool
+    else:
+        lib.MagickQuantizeImage.argtypes = [
+            c_void_p, c_size_t, c_int, c_size_t, c_int, c_bool
+        ]
+        lib.MagickQuantizeImage.restypes = c_bool
+        lib.MagickQuantizeImages.argtypes = [
+            c_void_p, c_size_t, c_int, c_size_t, c_int, c_bool
+        ]
+        lib.MagickQuantizeImages.restype = c_bool
     lib.MagickRaiseImage.argtypes = [
         c_void_p, c_size_t, c_size_t, c_ssize_t, c_ssize_t, c_bool
     ]
