@@ -96,7 +96,7 @@ class Color(Resource):
         self.dirty = False
         self.allocated = 0
         if raw is None:
-            if self.use_pixel:
+            if self.use_pixel:  # pragma: no cover
                 self.raw = ctypes.create_string_buffer(
                     ctypes.sizeof(PixelInfo)
                 )
@@ -128,7 +128,7 @@ class Color(Resource):
                 # Initialize resource.
                 self.resource = library.NewPixelWand()
                 # Restore color value from structure buffer.
-                if self.use_pixel:
+                if self.use_pixel:  # pragma: no cover
                     library.PixelSetPixelColor(self.resource, self.raw)
                 else:
                     library.PixelSetMagickColor(self.resource, self.raw)
@@ -753,7 +753,7 @@ def scale_quantum_to_int8(quantum):
     if quantum <= 0:
         return 0
     table = {8: 1, 16: 257.0, 32: 16843009.0, 64: 72340172838076673.0}
-    if MAGICK_HDRI:
+    if MAGICK_HDRI:  # pragma: no cover
         if QUANTUM_DEPTH == 8:
             v = quantum / table[QUANTUM_DEPTH]
         elif QUANTUM_DEPTH == 16:
